@@ -5,8 +5,17 @@ from yaml.constructor import Constructor as YamlConstructor, ConstructorError
 from yaml.nodes import MappingNode
 
 
+class uniqstr(str):
+    def __new__(cls, content):
+        return super().__new__(cls, content)
+
+
 class Constructor(YamlConstructor):
 
+    def __init__(self, register=None):
+        super(Constructor, self).__init__()
+        self.register = register
+
     def construct_mapping(self, node, deep=False):
         if not isinstance(node, MappingNode):
             raise ConstructorError(None, None,
@@ -23,3 +32,10 @@ class Constructor(YamlConstructor):
             value = self.construct_object(value_node, deep=deep)
             mapping[key] = value
         return mapping
+
+    def construct_scalar(self, node):
+        value = super().construct_scalar(node)
+        if isinstance(value, str) and node.style is not None:
+            value = uniqstr(value)
+            self.register.set(value, node.style)
+        return value
